@@ -32,21 +32,21 @@ AntChannel::AntChannel(const uchar ch)
 void
 AntChannel::addMsgListener2(AntListenerBase* lb)
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxListeners);
+  std::unique_lock<std::mutex> lock(m_mtxListeners);
   listeners.push_back(lb);
 }
 
 void
 AntChannel::rmMsgListener2(AntListenerBase* lb)
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxListeners);
+  std::unique_lock<std::mutex> lock(m_mtxListeners);
   listeners.remove(lb);
 }
 
 void
-AntChannel::onMsg(AntMessage &m)
+AntChannel::onMsg(const AntMessage &m)
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxListeners);
+  std::unique_lock<std::mutex> lock(m_mtxListeners);
   for(std::list<AntListenerBase*>::iterator i = listeners.begin(); i != listeners.end(); i++)
   {
     AntListenerBase* listener = *i;
@@ -57,7 +57,7 @@ AntChannel::onMsg(AntMessage &m)
 void
 AntChannel::interruptWait()
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxListeners);
+  std::unique_lock<std::mutex> lock(m_mtxListeners);
   for(std::list<AntListenerBase*>::iterator i = listeners.begin(); i != listeners.end(); i++)
   {
     AntListenerBase* listener = *i;
@@ -66,12 +66,20 @@ AntChannel::interruptWait()
 }
 
 void
-AntChannel::sanityCheck()
+AntChannel::sanityCheck(const char* caller)
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxListeners);
+  std::unique_lock<std::mutex> lock(m_mtxListeners);
   if(!listeners.empty())
   {
-    lprintf(LOG_DBG3, "sanityCheck[ch=%d] found %d leftover listeners\n", static_cast<int>(chan), static_cast<int>(listeners.size()));
+    lprintf(LOG_DBG3, "sanityCheck[ch=%d] found %d leftover listeners (caller=%s)\n", static_cast<int>(chan), static_cast<int>(listeners.size()), caller);
+    for(size_t i = 0; i < listeners.size(); i++)
+    {
+      std::list<AntListenerBase*>::iterator iter = listeners.begin();
+      std::advance(iter, i);
+      AntListenerBase* listener = *iter;
+      std::string s = listener->name();
+      lprintf(LOG_DBG3, "sanityCheck[ch=%d] found i=%zu %s\n", static_cast<int>(chan), i, s.c_str());
+    }
   }
 }
 
@@ -89,15 +97,14 @@ AntListenerBase::AntListenerBase(AntChannel& o)
 AntListenerBase::~AntListenerBase()
 {
   //FIXME: what happens if this dtor is called while an other thread is still executing waitForMsg() ?
-  //boost::unique_lock<boost::mutex> lock(m_mtxResp);
   owner.rmMsgListener2(this);
 }
 
 
 void
-AntListenerBase::onMsg(AntMessage& m)
+AntListenerBase::onMsg(const AntMessage &m)
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxResp);
+  std::unique_lock<std::mutex> lock(m_mtxResp);
   if(match(m))
   {
     //assert(!m_msgResp); //this assert won't always work: e.g. if the waitForMsg() already concluded, there is noone to reset this pointer
@@ -109,7 +116,7 @@ AntListenerBase::onMsg(AntMessage& m)
 void
 AntListenerBase::interruptWait()
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxResp);
+  std::unique_lock<std::mutex> lock(m_mtxResp);
   m_msgResp.reset();
   m_cndResp.notify_all(); // intentionally generate a "spurious" wakeup
 }
@@ -117,7 +124,7 @@ AntListenerBase::interruptWait()
 bool
 AntListenerBase::waitForMsg(AntMessage* m, const size_t timeout_ms)
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxResp);
+  std::unique_lock<std::mutex> lock(m_mtxResp);
   if(m_msgResp) // it had already arrived
   {
     if(m) *m = *m_msgResp;
@@ -125,7 +132,9 @@ AntListenerBase::waitForMsg(AntMessage* m, const size_t timeout_ms)
     //lprintf(LOG_DBG3, "waitForMsg [0] already arrived\n");
     return true;
   }
-  if(!m_cndResp.timed_wait(lock, boost::posix_time::milliseconds(timeout_ms)))
+  using namespace std::chrono_literals;
+  auto td = timeout_ms*1ms;
+  if(std::cv_status::timeout == m_cndResp.wait_for(lock, td))
   {
     // false means, timeout was reached
     //lprintf(LOG_DBG3, "waitForMsg [1] timeout\n");
@@ -152,7 +161,7 @@ AntListenerBase::waitForMsg(AntMessage* m, const size_t timeout_ms)
 
 
 bool
-AntEvListener::match(AntMessage& other) const
+AntEvListener::match(const AntMessage& other) const
 {
   return other.getMsgId()==MESG_RESPONSE_EVENT_ID
       && owner.getChan() == other.getPayloadRef()[0]
@@ -178,7 +187,7 @@ AntEvListener::waitForEvent(uint8_t& msgCode, const size_t timeout_ms)
 
 
 bool
-AntRespListener::match(AntMessage& other) const
+AntRespListener::match(const AntMessage& other) const
 {
   return other.getMsgId()==MESG_RESPONSE_EVENT_ID
       && owner.getChan() == other.getPayloadRef()[0]
@@ -206,7 +215,7 @@ AntRespListener::waitForResponse(uint8_t& respVal, const size_t timeout_ms)
 
 
 bool
-AntReqListener::match(AntMessage& other) const
+AntReqListener::match(const AntMessage &other) const
 {
   bool matched = other.getMsgId()==msgId
     && other.getPayloadRef()[0]==chan;
@@ -220,11 +229,11 @@ AntReqListener::match(AntMessage& other) const
 
 
 bool
-AntBCastListener::match(AntMessage& other) const
+AntBCastListener::match(const AntMessage &other) const
 {
   return other.getMsgId()==MESG_BROADCAST_DATA_ID
       && other.getPayloadRef()[0]==owner.getChan()
-      && other.getPayloadRef()[1]==first;
+      && (other.getPayloadRef()[1]==ANTFS_BeaconId || other.getPayloadRef()[1]==ANTFS_CommandResponseId);
 }
 
 bool
@@ -248,9 +257,9 @@ AntBCastListener::waitForBCast(AntMessage& bcast, const size_t timeout_ms)
 
 
 void
-AntBurstListener::onMsg(AntMessage& m)
+AntBurstListener::onMsg(const AntMessage &m)
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxResp);
+  std::unique_lock<std::mutex> lock(m_mtxResp);
   if(match(m))
   {
     m_bursts.push_back(m);
@@ -261,7 +270,7 @@ AntBurstListener::onMsg(AntMessage& m)
 void
 AntBurstListener::interruptWait()
 {
-  boost::unique_lock<boost::mutex> lock(m_mtxResp);
+  std::unique_lock<std::mutex> lock(m_mtxResp);
   m_bursts.clear();
   m_cndResp.notify_all(); // intentionally generate a "spurious" wakeup
 }
@@ -269,7 +278,7 @@ AntBurstListener::interruptWait()
 
 
 bool
-AntBurstListener::match(AntMessage& other) const
+AntBurstListener::match(const AntMessage &other) const
 {
   const M_ANT_Burst* burst(reinterpret_cast<const M_ANT_Burst*>(other.getPayloadRef()));
   return other.getMsgId()==MESG_BURST_DATA_ID
@@ -281,14 +290,16 @@ bool
 AntBurstListener::waitForBursts(std::list<AntMessage>& bs, const size_t timeout_ms)
 {
   bs.clear();
-  boost::unique_lock<boost::mutex> lock(m_mtxResp);
+  std::unique_lock<std::mutex> lock(m_mtxResp);
   if(!m_bursts.empty()) // some had already arrived
   {
     std::swap(bs, m_bursts);
     return true;
   }
   // TODO: handle arrival of event:EVENT_RX_FAIL
-  if(!m_cndResp.timed_wait(lock, boost::posix_time::milliseconds(timeout_ms)))
+  using namespace std::chrono_literals;
+  auto td = timeout_ms*1ms;
+  if(std::cv_status::timeout == m_cndResp.wait_for(lock, td))
   {
     // // false means, timeout was reached
     return false;
@@ -307,21 +318,25 @@ AntBurstListener::waitForBursts(std::list<AntMessage>& bs, const size_t timeout_
 bool
 AntBurstListener::collectBurst(std::vector<uint8_t>& burstData, const size_t timeout_ms)
 {
-  boost::posix_time::ptime start = boost::posix_time::microsec_clock::local_time();
-  boost::posix_time::ptime end = start+boost::posix_time::milliseconds(timeout_ms);
+  using sc = std::chrono::system_clock;
+  using namespace std::chrono_literals;
+  auto td = timeout_ms*1ms;
+  std::chrono::system_clock::time_point start = std::chrono::system_clock::now();
+  std::chrono::system_clock::time_point end = start + td;
 
-  boost::posix_time::ptime after=start;
-  boost::posix_time::time_duration remaining = end-after;
+  std::chrono::system_clock::time_point after = start;
+  std::chrono::system_clock::duration remaining = end - after;
   uchar expectedSeq=0;
   bool found=false;
   bool lastFound=false;
-  while(remaining>boost::posix_time::time_duration(boost::posix_time::milliseconds(0)))
+  while(remaining > sc::duration(0ms))
   {
     std::list<AntMessage> msgs;
-    size_t left_ms=static_cast<size_t>(remaining.total_milliseconds());
+    size_t left_ms=static_cast<size_t>(std::chrono::duration_cast<std::chrono::milliseconds>(remaining).count());
+    //size_t left_ms=static_cast<size_t>(remaining.total_milliseconds());
     //printf("msg wait ms=%d\n",  int(left_ms));
     CHECK_RETURN_FALSE(waitForBursts(msgs, left_ms));
-    after = boost::posix_time::microsec_clock::local_time();
+    after = sc::now();  // TODO: should this be std::chrono::high_resolution_clock::now(); ?
     remaining = end-after;
     for(std::list<AntMessage>::iterator i = msgs.begin(); i != msgs.end(); i++)
     {
