@@ -31,7 +31,6 @@
 #include <vector>
 #include <string>
 #include <chrono>
-#include <boost/thread/thread_time.hpp>
 #include <iostream>
 #include "stdintfwd.hpp"
 
@@ -83,7 +82,6 @@ AntFr310XT::AntFr310XT(Serial *s)
   , m_antMessenger(new AntMessenger())
   , clientState(BUSY)
   , state(ST_ANTFS_0)
-  , m_eventThKill(0)
   , m_restartCount(0)
   , aplc(getConfigFolder()+std::string("antparse_")+getDateString()+".txt")
   , clientSN(0)
@@ -98,7 +96,7 @@ AntFr310XT::AntFr310XT(Serial *s)
 
   AntFr310XT_EventLoop eventTh;
   eventTh.rv=0;
-  m_eventTh = boost::thread(eventTh, this);
+  m_eventTh = std::thread(eventTh, this);
 
 }
 
@@ -110,8 +108,11 @@ AntFr310XT::~AntFr310XT()
     m_antMessenger->setCallback(0);
   }
 
-  m_eventThKill=1;
-  m_eventTh.join();
+  m_eventThKill=true;
+  if(m_eventTh.joinable())
+  {
+    m_eventTh.join();
+  }
   state = ST_ANTFS_0;
 
   m_antMessenger.reset();
@@ -193,14 +194,14 @@ AntFr310XT::run()
 void
 AntFr310XT::stop()
 {
-  assert(boost::this_thread::get_id() == this->m_eventTh.get_id());
-  m_eventThKill = 1;
+  assert(std::this_thread::get_id() == this->m_eventTh.get_id());
+  m_eventThKill = true;
   // stop() is called from the event thread
   // terminate called after throwing an instance of 'boost::exception_detail::clone_impl<boost::exception_detail::error_info_injector<boost::thread_resource_error> >'
   //   what():  boost thread: trying joining itself: Resource deadlock avoided
   //m_eventTh.join();
 
-  m_antMessenger->kill();
+  if(m_antMessenger) m_antMessenger->kill();
   if(m_serial && m_serial->isOpen())
   {
     if(state>ST_ANTFS_LINKING)
@@ -220,7 +221,7 @@ AntFr310XT::stop()
 void
 AntFr310XT::stopAsync()
 {
-  assert(boost::this_thread::get_id() != this->m_eventTh.get_id());
+  assert(std::this_thread::get_id() != this->m_eventTh.get_id());
 
 
   LOG(LOG_WARN) << "stopAsync called!\n\n";
@@ -235,14 +236,12 @@ AntFr310XT::stopAsync()
 const int
 AntFr310XT::getSMState() const
 {
-  //boost::unique_lock<boost::mutex> lock(this->stateMtx); // not needed, as this is a atomic read
   return state;
 }
 
 const char*
 AntFr310XT::getSMStateStr() const
 {
-  //boost::unique_lock<boost::mutex> lock(this->stateMtx); // not needed, as this is a atomic read
   return StateFSWork2Str(state);
 }
 
@@ -282,7 +281,7 @@ AntFr310XT::handleEvents()
 {
 #define changeStateSafe(x) do                                           \
   {                                                                     \
-    boost::unique_lock<boost::mutex> lock(this->stateMtx);              \
+    std::unique_lock<std::mutex> lock(this->stateMtx);              \
     if(this->state == ST_ANTFS_LAST)                                    \
     {                                                                   \
       lock.unlock();                                                    \
@@ -298,7 +297,7 @@ AntFr310XT::handleEvents()
 
 #define checkForExit() do                                               \
   {                                                                     \
-    boost::unique_lock<boost::mutex> lock(this->stateMtx);              \
+    std::unique_lock<std::mutex> lock(this->stateMtx);              \
     if(this->state == ST_ANTFS_LAST)                                    \
     {                                                                   \
       lock.unlock();                                                    \
@@ -437,11 +436,12 @@ AntFr310XT::handleEvents()
 
     LOG(LOG_RAW) << "\n\nFound client \"" << clientDevName << "\" SN=0x" << toString<uint>(clientSN,8,'0') << " SN=" << clientSN << "\n\n\n";
 
-    m_ds.reset(new DeviceSettings(toStringDec<uint>(clientSN).c_str()));
+    m_ds.reset(new DeviceSettings(clientDevName, toStringDec<uint>(clientSN)));
     assert(m_ds.get());
     m_ds->loadDefaultValues();
     LOG_VAR(m_ds->getConfigFileName());
     m_ds->loadFromFile(m_ds->getConfigFileName());
+    mkDir(m_ds->getFolder().c_str());
     m_ds->saveToFile(m_ds->getConfigFileName());
     m_serial->setWriteDelay(m_ds->SerialWriteDelayMs);
 
@@ -471,6 +471,7 @@ AntFr310XT::handleEvents()
   }
   else if(state == ST_ANTFS_AUTH1_PASS)
   {
+    bool is_fr405 = clientDevName=="Forerunner 405" || clientDevName=="Forerunner 410" || isAntpm405Override();
     CHECK_RETURN_FALSE_LOG_OK_DBG2(m_antMessenger->ANT_RequestMessage(chan, MESG_CHANNEL_STATUS_ID));
 
     if(!m_antMessenger->ANTFS_Authenticate(chan, hostSN, pairedKey))
@@ -484,7 +485,7 @@ AntFr310XT::handleEvents()
     // channel status <>
     CHECK_RETURN_FALSE_LOG_OK_DBG2(m_antMessenger->ANT_RequestMessage(chan, MESG_CHANNEL_STATUS_ID));
 
-    if(clientDevName=="Forerunner 405" || clientDevName=="Forerunner 410" || isAntpm405Override())
+    if(is_fr405)
       changeStateSafe(ST_ANTFS_GINTF_DL_CAPS);
     else if(mode==MD_DOWNLOAD_ALL || mode==MD_DIRECTORY_LISTING)
       changeStateSafe(ST_ANTFS_DL_DIRECTORY);
@@ -521,7 +522,8 @@ AntFr310XT::handleEvents()
     LOG_VAR(zfc.activityFiles.size());
     LOG_VAR(zfc.courseFiles.size());
     LOG_VAR(zfc.waypointsFiles.size());
-    zfc.cullFitFiles(db);
+    // zfc.cullFitFiles(db); // this culling strategy does not work well, because fit files are given new indices on the device after a download
+    zfc.cullFitFilesDate();
     LOG_VAR(zfc.activityFiles.size());
     LOG_VAR(zfc.courseFiles.size());
     LOG_VAR(zfc.waypointsFiles.size());
@@ -804,7 +806,7 @@ AntFr310XT::handleEvents()
     // R   3.258 MESG_BURST_DATA_ID chan=0x00, seq=1, last=yes 322e383000000000 2.80....
     uint64_t code = 0xfe00000000000000;
     CHECK_RETURN_FALSE_LOG_OK(m_antMessenger->ANTFS_Direct(chan, SwapDWord(code), data));
-    {GFile file0; file0.bytes=data; file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
+    {GFile file0(data); file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
 
     // GPS version
 //    S  48.159 MESG_BURST_DATA_ID chan=0x00, seq=0, last=no  ANTFS_CMD(0x44) ANTFS_CmdDirect fd=0xffff, offset=0x0000, data=0x0000
@@ -823,7 +825,7 @@ AntFr310XT::handleEvents()
 //    R   3.124 MESG_BURST_DATA_ID chan=0x00, seq=3, last=yes 322e313000000000 2.10....
     code = 0x06000200ff000000;
     CHECK_RETURN_FALSE_LOG_OK(m_antMessenger->ANTFS_Direct(chan, SwapDWord(code), data));
-    {GFile file0; file0.bytes=data; file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
+    {GFile file0(data); file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
 
     // 06000200f8000000 = capabilities
 //    S   6.746 MESG_BURST_DATA_ID chan=0x00, seq=0, last=no  ANTFS_CMD(0x44) ANTFS_CmdDirect fd=0xffff, offset=0x0000, data=0x0000
@@ -860,35 +862,35 @@ AntFr310XT::handleEvents()
 //    R   3.122 MESG_BURST_DATA_ID chan=0x00, seq=3, last=yes f60344f903000000 ..D.....
     code = 0x06000200f8000000;
     CHECK_RETURN_FALSE_LOG_OK(m_antMessenger->ANTFS_Direct(chan, SwapDWord(code), data));
-    {GFile file0; file0.bytes=data; file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
+    {GFile file0(data); file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
 
     // 0x060002001b000000 pid=0x001b=27 L001_Pid_Records
     code = 0x060002001b000000;
     CHECK_RETURN_FALSE_LOG_OK(m_antMessenger->ANTFS_Direct(chan, SwapDWord(code), data));
-    {GFile file0; file0.bytes=data; file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
+    {GFile file0(data); file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
 
     // 0x06000200de030000 pid=0x03de=990 L001_Pid_Run
     code = 0x06000200de030000;
     CHECK_RETURN_FALSE_LOG_OK(m_antMessenger->ANTFS_Direct(chan, SwapDWord(code), data));
-    {GFile file0; file0.bytes=data; file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
+    {GFile file0(data); file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
 
 
     // 0x0600020095000000 pid=0x0095=149 L001_Pid_Lap
     code = 0x0600020095000000;
     CHECK_RETURN_FALSE_LOG_OK(m_antMessenger->ANTFS_Direct(chan, SwapDWord(code), data));
-    {GFile file0; file0.bytes=data; file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
+    {GFile file0(data); file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
 
 
     // 0x0600020063000000 pid=0x0063=99 L001_Pid_Trk_Hdr
     code = 0x0600020063000000;
     CHECK_RETURN_FALSE_LOG_OK(m_antMessenger->ANTFS_Direct(chan, SwapDWord(code), data));
-    {GFile file0; file0.bytes=data; file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
+    {GFile file0(data); file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
 
 
     // 0x06000200e6050000 pid=0x05e6=1510 ????_Pid_Unknown
     code = 0x06000200e6050000;
     CHECK_RETURN_FALSE_LOG_OK(m_antMessenger->ANTFS_Direct(chan, SwapDWord(code), data));
-    {GFile file0; file0.bytes=data; file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
+    {GFile file0(data); file0.saveToFile((folder+toString(code, 16, '0')+".bin").c_str());}
 
 
     // just exit
@@ -911,7 +913,7 @@ AntFr310XT::handleEvents()
 int
 AntFr310XT::changeState(const int newState, bool force)
 {
-  boost::unique_lock<boost::mutex> lock(stateMtx);
+  std::unique_lock<std::mutex> lock(stateMtx);
   int oldState = this->state;
   if(oldState == ST_ANTFS_LAST && newState != ST_ANTFS_LAST&& !force)
   {
