@@ -29,8 +29,6 @@
 #include <iostream>
 #include <chrono>
 #include "common.hpp"
-#include <boost/thread/thread_time.hpp>
-#include <boost/foreach.hpp>
 
 #include "Log.hpp"
 
@@ -58,17 +56,15 @@ struct AntMessenger_Recevier
 
 
 AntMessenger::AntMessenger()
-  : m_io(0)
-  , m_cb(0)
-  , m_packerThKill(0)
-  , m_rpackQueue2()
+  : m_rpackQueue2()
 {
-  m_packerThKill = 0;
   AntMessenger_Recevier msgTh;
   msgTh.rv=0;
-  m_packerTh = boost::thread(msgTh, this);
+  m_packerTh = std::thread(msgTh, this);
 
-  m_rpackQueue2.setOnDataArrivedCallback(std::bind1st(std::mem_fun(&AntMessenger::onMessage), this));
+  m_rpackQueue2.setOnDataArrivedCallback([&](const std::vector<AntMessage>& v) -> bool {
+      return onMessage(v);
+  });
 
   for(int i=0; i < ANTPM_MAX_CHANNELS; i++)
   {
@@ -82,8 +78,11 @@ AntMessenger::AntMessenger()
 AntMessenger::~AntMessenger()
 {
   m_rpackQueue2.setOnDataArrivedCallback(0);
-  m_packerThKill = 1;
-  m_packerTh.join();
+  m_packerThKill = true;
+  if(m_packerTh.joinable())
+  {
+    m_packerTh.join();
+  }
   m_io=0;
   m_cb=0;
   lprintf(LOG_DBG2, "%s\n", __FUNCTION__);
@@ -576,6 +575,9 @@ AntMessenger::ANTFS_Download( const uchar chan, const ushort file, std::vector<u
   uint nextOffset = 0;
   do
   {
+    if(interrupted)
+      return false;
+
     //fprintf(loggerc(), "dlIter=%lu, crc=0x%04x, off=0x%08x\n", (unsigned long)dlIter, crc, nextOffset);
     //LOG_VAR2(dlIter, toString(crc,4,'0'));
     M_ANTFS_Command_Download dl;
@@ -693,7 +695,8 @@ AntMessenger::ANTFS_Download( const uchar chan, const ushort file, std::vector<u
 
     CHECK_RETURN_FALSE(ANT_RequestMessage(chan, MESG_CHANNEL_STATUS_ID));
 
-    LOG(antpm::LOG_RAW) << "\n\nFile " << toString(file,4,'0') << ", downloaded " << std::dec << c2 << " of " << fileSize << " bytes. Total " << data.size() << " downloaded.\n\n";
+    LOG(antpm::LOG_RAW) << "\n\nFile " << toString(file,4,'0') << ", downloaded " << std::dec << c2 << " bytes. Total "
+                        << data.size() << " / " << fileSize << " downloaded (" << static_cast<double>(data.size())/fileSize*100.0 << "%).\n\n";
     // TODO: keep reading until there is data left
     dlIter += 1;
   } while((data.size()<fileSize) /*&& (dlIter++<ANTPM_RETRIES)*/ );
@@ -759,12 +762,14 @@ AntMessenger::ANTFS_RequestClientDeviceSerialNumber(const uchar chan, const uint
   cmd.detail.authenticate.authStrLen = 0;
   cmd.detail.authenticate.sn = hostSN;
 
+  CHECK_RETURN_FALSE_LOG_OK_DBG2(ANT_SendAcknowledgedData(chan, reinterpret_cast<uchar*>(&cmd), 2000));
+
+  {
   AntChannel& pc = *chs[chan].get();
   AntBurstListener bl(pc);
   //pc.addMsgListener(&bl);
 
 
-  CHECK_RETURN_FALSE_LOG_OK_DBG2(ANT_SendAcknowledgedData(chan, reinterpret_cast<uchar*>(&cmd), 2000));
 
   std::vector<uchar> burstData;
   /*bool rv =*/ bl.collectBurst(burstData, 5000);
@@ -777,14 +782,23 @@ AntMessenger::ANTFS_RequestClientDeviceSerialNumber(const uchar chan, const uint
   //
   //CHECK_RETURN_FALSE_LOG_OK(waitForBurst(chan, burstData, 30000));
   LOG_VAR_DBG2(burstData.size());
-  CHECK_RETURN_FALSE_LOG_OK_DBG2(burstData.size()==4*8);
+  CHECK_RETURN_FALSE_LOG_OK_DBG2(burstData.size()==4*8 || burstData.size()==2*8);
 
   const M_ANTFS_Response* cmdResp(reinterpret_cast<const M_ANTFS_Response*>(&burstData[8]));
   sn = cmdResp->detail.authenticateResponse.sn;
   uchar lenDevName=cmdResp->detail.authenticateResponse.authStrLen; // 16 for 310XT, 14 for 410
-  CHECK_RETURN_FALSE_LOG_OK_DBG2(lenDevName>0);
+  LOG_VAR_DBG2(static_cast<int>(lenDevName));
+  if(burstData.size()==32)
+  {
+    CHECK_RETURN_FALSE_LOG_OK_DBG2(lenDevName>0);
 
-  devName = std::string(reinterpret_cast<const char*>(&burstData[16]), lenDevName);
+    devName = std::string(reinterpret_cast<const char*>(&burstData[16]), lenDevName);
+  }
+  else
+  {
+    devName = "Forerunner 405";
+  }
+  }
 
   logger() << "devName = \"" << devName << "\"\n";
 
@@ -808,6 +822,8 @@ AntMessenger::ANTFS_Direct(const uchar chan, const uint64_t code, std::vector<ui
   bool sentDirect = false;
   for(int i = 0; i < ANTPM_RETRIES; i++)
   {
+    if(interrupted)
+      return false;
     sentDirect = false;
 
     LOG_VAR(waitForBroadcast(chan));
@@ -917,7 +933,7 @@ AntMessenger::sendCommand(AntMessage &m, const size_t timeout_ms)
   }
   }
 
-  sanityCheck();
+  sanityCheck(__FUNCTION__);
 
   return true;
 }
@@ -952,7 +968,7 @@ AntMessenger::sendRequest(uchar reqMsgId, uchar chan, AntMessage *response, cons
 
   //pc.rmMsgListener(&rl);
   }
-  sanityCheck();
+  sanityCheck(__FUNCTION__);
 
   return rv;
 }
@@ -970,7 +986,7 @@ bool AntMessenger::writeMessage(AntMessage &m)
     return false;
 
   m.sent=true;
-  m.timestamp = boost::get_system_time();
+  m.timestamp = std::chrono::system_clock::now();
   m.idx = packetIdx++;
   assert(m.vrfChkSum());
 
@@ -1030,7 +1046,7 @@ AntMessenger::sendAckData(const uchar chan, const uchar data[8], const size_t ti
     }
     rv = rv && found;
   }
-  sanityCheck();
+  sanityCheck(__FUNCTION__);
 
   return rv;
 }
@@ -1067,12 +1083,12 @@ AntMessenger::assemblePackets(std::list<uchar>& q)
     {
       q.pop_front();
     }
-    m.timestamp = boost::get_system_time();
+    m.timestamp = std::chrono::system_clock::now();
     m.idx = packetIdx++;
     m_rpackQueue2.push(m);
     if(m_cb)
     {
-      m_cb->onAntReceived(m);
+      m_cb->onAntReceived(std::move(m));
     }
 
   }
@@ -1084,14 +1100,14 @@ AntMessenger::assemblePackets(std::list<uchar>& q)
 
 /// Called from m_rpackQueue2.eventLoop()
 bool
-AntMessenger::onMessage(std::vector<AntMessage> v)
+AntMessenger::onMessage(const std::vector<AntMessage> &v)
 {
   //TODO: don't presort here, but call onMsg for all incoming packets
 
   //lprintf(antpm::LOG_DBG3, "%d\n", int(v.size()));
   for(size_t i = 0; i < v.size(); i++)
   {
-    AntMessage& m(v[i]);
+    const AntMessage& m(v[i]);
     lprintf(antpm::LOG_DBG3, "%s\n", m.str().c_str());
 
     if(m.getMsgId()==MESG_RESPONSE_EVENT_ID
@@ -1124,7 +1140,7 @@ AntMessenger::onMessage(std::vector<AntMessage> v)
     }
     else
     {
-      lprintf(antpm::LOG_WARN, "unhandled 0x%0x\n", (int)m.getMsgId());
+      lprintf(antpm::LOG_WARN, "unhandled 0x%0x %s\n", (int)m.getMsgId(), m.msgId2Str(m.getMsgId()).c_str());
     }
 
   }
@@ -1132,11 +1148,11 @@ AntMessenger::onMessage(std::vector<AntMessage> v)
 }
 
 
-void AntMessenger::sanityCheck()
+void AntMessenger::sanityCheck(const char *caller)
 {
   for(int i=0; i < ANTPM_MAX_CHANNELS; i++)
   {
-    chs[i]->sanityCheck();
+    chs[i]->sanityCheck(caller);
   }
 
 }
@@ -1169,7 +1185,7 @@ AntMessenger::waitForBurst(const uchar chan,
   }
   }
 
-  sanityCheck();
+  sanityCheck(__FUNCTION__);
 
   return true;
 }
@@ -1178,12 +1194,11 @@ AntMessenger::waitForBurst(const uchar chan,
 bool
 AntMessenger::waitForBroadcast(const uchar chan, AntMessage* reply, const size_t timeout_ms)
 {
-  const uchar first=ANTFS_BeaconId;
   bool found=false;
 
   AntChannel& pc = *chs[chan].get();
   {
-  AntBCastListener bcl(pc, first);
+  AntBCastListener bcl(pc);
   //pc.addBCastListener(&bcl);
 
   AntMessage dummy;if(!reply) reply=&dummy;
@@ -1192,11 +1207,12 @@ AntMessenger::waitForBroadcast(const uchar chan, AntMessage* reply, const size_t
   //M_ANTFS_Beacon* beacon(reinterpret_cast<M_ANTFS_Beacon*>(&reply->getPayloadRef()[1]));
   if(!found)
   {
-    lprintf(antpm::LOG_ERR, "no matching bcast before timeout\n"); fflush(stdout);
-  }
+    lprintf(antpm::LOG_ERR, "no matching bcast before timeout ch=%d\n", static_cast<int>(chan)); fflush(stdout);
   }
 
-  sanityCheck();
+  }
+
+  sanityCheck(__FUNCTION__);
   
   return found;
 }
@@ -1210,7 +1226,9 @@ AntMessenger::interruptWait()
     chs[i]->interruptWait();
   }
 
-  sanityCheck();
+  interrupted = true;
+
+  sanityCheck(__FUNCTION__);
 }
 
 
